# atomkraft

Testing for Cosmos Blockchains

### Using `pip` (inside a system or virtual env)

```
pip install git+https://github.com/informalsystems/atomkraft@dev
atomkraft --help
```

### Using `poetry` (inside a project)

```
poetry add git+https://github.com/informalsystems/atomkraft#dev
poerty run atomkraft
```
